Date: 07 12, 2001 12:25:17 PM

Viewing Parse Tree Matches

You can select a specific pass in the analyzer sequence and view the parse tree for that pass only.

To view a partial parse tree:

1. In the Ana Tab, select the pass in the analyzer sequence.

2. Right-click and select View > Tree Matches

Note: To view the parse tree for a single pass, you must run the analyzer with the Generate Logs button on.

## See Also

Viewing Parse Trees

Viewing Concept Trees

Viewing Intermediate Trees

Viewing Partial Trees

Viewing Final Trees